
component {
	property name="gdprService" inject="gdprService";
	property name="visitorService" inject="WebsiteVisitorService";
	property name="PermissionDao" inject="presidecms:object:gdprpermission";


	public query function getGroups(event, rc, prc, args={} ) {
		return gdprService.getGroups(rc.shortcode?:"");
	}

	public query function getItems(event, rc, prc, args={} ) {
		return gdprService.getItems(rc.shortcode?:"");
	}

	public function getGroupsWithItems(event, rc, prc, args={} ) {
		return gdprService.getGroupsWithItems(rc.shortcode?:"");
	}

	private string function _gdprDialog( event, rc, prc, arg={} ) {
		var args = duplicate( arguments.args );
		
		if(prc.presidepage.page_type == "gdpr") {
			// Don't show Dialog on settings page
			args.showCookieConsentModal = false;
		} else {
			// Check if visitor has already a record in DB
			var check = PermissionDao.selectData(filter = {visitorid = visitorService.getVisitorId() });

			args.showCookieConsentModal = isEmpty(check);
		}
		
		// Get Settings
		prc.gdprSettings = {};
		prc.gdprSettings.configBtnTxt    = getSystemSetting(category = "gdprsettings" , setting  = "configBtnTxt"    , default="Einstellungen");
		prc.gdprSettings.acceptAllBtnTxt = getSystemSetting(category = "gdprsettings" , setting  = "acceptAllBtnTxt" , default="Alle akzeptieren");
		prc.gdprSettings.disclaimer      = getSystemSetting(category = "gdprsettings" , setting  = "disclaimer"      , default="Kofigurieren Sie den Hinweistext in den Systemeinstellungen");
		
		
		event.includeData( data={ showCookieConsentModal = args.showCookieConsentModal } )
		     .include( assetId="gdpr-modal-css" )
				 .include( assetId="gdpr-js" )
		     .include( assetId="gdrp-toggle-css" )
				 .include( assetId="gdrp-toggle-js" )
				 ;

		return renderView( view="/general/_gdprDialog", args=args );
	}
	
	public void function test() {
		dump(var = getGroups(), label = "getGroups()");
		dump(var = getItems(), label = "getItems()");
		dump(var = getGroupsWithItems(), label = "getGroupsWithItems()");
		abort;
	}

	public function AcceptAllPermissions(event, rc, prc, args={} ) {
		var visitorID = visitorService.getVisitorId(); // create VistorID

		var itemList = getItems();
		
		for(var item in itemList) {
			// Permission exists?
			check = PermissionDao.selectData(filter = {item = item.id,visitorid = visitorId});
			if(!isEmpty(check)) {
				result = PermissionDao.updateData(
				data = {allowed = 1},
				filter = {item = item.id,visitorid = visitorId}
				);
			} else {
				result = PermissionDao.insertData(
				data = {
						item = item.id,
						visitorid = visitorId,
						allowed = 1
					}
				);
			}
		
		}
		return true;
	}

	public function saveItemPermissions(event, rc, prc, args={} ) {
		var visitorID = visitorService.getVisitorId(); // create VistorID
		var formData  = event.getCollectionForForm();  // get Items from form submission

		var itemList = formData.keyList();
		var result = "";
		var check ="";
		
		
		for(var formItem in itemList) {
			// Permission exists?
			check = PermissionDao.selectData(filter = {item = listLast(formItem,"_"),visitorid = visitorId});
			if(!isEmpty(check)) {
				result = PermissionDao.updateData(
				data = {allowed = val(formData[formItem])},
				filter = {item = listLast(formItem,"_"),visitorid = visitorId}
				);
			} else {
				result = PermissionDao.insertData(
				data = {
						item = listLast(formItem,"_"),
						visitorid = visitorId,
						allowed = val(formData[formItem])
					}
				);
			}
		
		}
	}

}